use std::io::BufReader;

use clap::Parser;

mod cli;
use clap_verbosity_flag::{LogLevel, InfoLevel};
use cli::*;

mod scanner;
use scanner::scan;

fn main() -> std::io::Result<()> {
    let cli = Cli::parse();
    match cli.command {
        Commands::Scan => {
            let mut buf: String = String::new();

            if cli.stdin {
                for line in std::io::stdin().lines() {
                    match line {
                        Ok(line) => buf = format!("{buf}\n{line}"),
                        Err(err) => eprintln!("IO error while reading stdin: {err}")
                    }
                }
            }
            else if cli.files.len() >= 1 {
                for file in cli.files {
                    buf += &std::fs::read_to_string(file)?;
                }
            }

            if cli.verbose {
                println!("{text:=^80}\n{buf}\n{text:=^80}", text = "raw combined source");
            }
            let result = scan(&buf);
            for i in result { println!("\"{i}\"\n")}
        }
    }
    Ok(())
}
